==> cmsmadesimple-1.8.2p0.tgz: cms/modules/ModuleManager/lang/ext/nb_NO.php <==
<?php
$lang['available_updates'] = 'Moduler tilgjengelige for oppdatering';
$lang['all_modules_up_to_date'] = 'Det er ikke tilgjengelig noen nyere moduler i biblioteket';
$lang['error_module_object'] = 'Feil: Fant ikke en forekomst av %s modulen';
$lang['error_nomatchingmodules'] = 'Feil: kunne ikke finne noen matchende moduler i biblioteket';
$lang['error_nomodules'] = 'Feil: kunne ikke hente listen over installerte moduler';
$lang['upgrade_available'] = 'Nyere versjon tilgjengelig (%s), du har (%s)';
$lang['newversions'] = 'Installerte moduler';
$lang['error_depends'] = 'En eller flere avhengigheter er ikke installert. Du b&oslash;r installere avhengigheter f&oslash;rst';
$lang['notice_depends'] = '%s krever f&oslash;lgende handling. Klikk p&aring;  &quot;Installer&quot; for &aring; fortsette.';
$lang['install_submit'] = 'Installer';
$lang['depend_upgrade'] = 'Modul %s trenger &aring; oppgraderes til versjon %s.';
$lang['depend_install'] = 'Modul %s (versjon %s eller senere) m&aring; v&aelig;re installert';
$lang['depend_activate'] = 'Modul %s trenger &aring; aktiveres.';
$lang['action_activated'] = 'Modul %s har blitt aktivert.';
$lang['action_installed'] = 'Modul %s har blitt installert med f&oslash;lgende melding(er): %s';
$lang['action_upgraded'] = 'Modul %s har blitt oppgradert med f&oslash;lgende melding(er): %s';
$lang['title_installation_complete'] = 'Installasjonsprosessen fullf&oslash;rt!';
$lang['install_with_deps'] = 'Evaluere alle avhengigheter og installer';
$lang['msg_nodependencies'] = 'Denne filen har ikke oppf&oslash;rt noen avhengigheter';
$lang['error_upgrade'] = 'Oppgradering av modul %s feilet!';
$lang['error_skipping'] = 'Hopper over installering/oppgradering av %s p&aring; grunn av feil med &aring; sette opp avhengighetene. Vennligst se meldingen overfor, og fors&oslash;k igjen.';
$lang['dependstxt'] = 'Avhengigheter';
$lang['use_at_your_own_risk'] = 'Bruk p&aring; egen risiko';
$lang['compatibility_disclaimer'] = 'Modulene som vises her er bidratt med av b&aring;de CMS utviklerne og tredjepartsutviklere. Vi gir ingen garanti for at modulene som er tilgjengelige her fungerer, testet, eller kompatible med ditt system. Du oppfordres til &aring; lese informasjonen du finner i hjelp og i &quot;Om&quot; linkene for hver modul f&oslash;r du fors&oslash;ker &aring; installere.';
$lang['notice'] = 'Merk';
$lang['general_notice'] = 'Versjonene som vises her representerer de siste XML filene som er lastet opp til ditt valgte modulbibliotek (vanligvis er dette CMS %s).  De b&oslash;r (men med unntak) representere de siste tilgjengelige versjonene.';
$lang['incompatible'] = 'Ikke kompatibel';
$lang['prompt_settings'] = 'Innstillinger';
$lang['prompt_otheroptions'] = 'Andre opsjoner';
$lang['reset'] = 'Nullstill';
$lang['error_permissions'] = '<strong><em>ADVARSEL:</em></strong> Ikke tilstrekkelige katalog rettigheter for &aring; installere moduler. Du kan ogs&aring; erfare problemer med PHP Safe mode. Vennligst sjekk at safe mode ikke er p&aring;sl&aring;tt og at filsystem rettighetene er tilstrekkelige.';
$lang['error_minimumrepository'] = 'Lager-versjonen er ikke kompatibel med denne modulbehandleren';
$lang['prompt_reseturl'] = 'Sett URL til forh&aring;ndssatt standard';
$lang['prompt_resetcache'] = 'Nullstill lokalt mellomlager for Lager data';
$lang['prompt_dl_chunksize'] = 'Nedlastings bolk-st&oslash;rrelse (Kb)';
$lang['text_dl_chunksize'] = 'Maksimum mengde data &aring; laste ned fra serveren i en bolk (under installering av en modul)';
$lang['error_nofilesize'] = 'Ingen filst&oslash;rrelses parameter oppgitt';
$lang['error_nofilename'] = 'Ingen filnavn parameter oppgitt';
$lang['error_unsatisfiable_dependency'] = 'Kan ikke finne den p&aring;krevde modulen &quot;%s&quot; (versjon %s eller senere) i biblioteket. Denne er direkte p&aring;krevd av %s; dette kan indikere at det er et problem med denne versjonen av modulen i biblioteket. Vennligst kontakt denne modulens opphavsmann.  Avbryter.';
$lang['error_checksum'] = 'Sjekksum feil.  Dette indikerer sansynligvis en korrupt til, enten n&aring;r den ble lastet opp til lagringsplassen, eller et problem med overf&oslash;ring ned til din maskin.';
$lang['cantdownload'] = 'Kan ikke laste ned';
$lang['download'] = 'Last ned og Installer';
$lang['error_moduleinstallfailed'] = 'Modul installasjonen feilet';
$lang['error_connectnomodules'] = 'Selvom tilkobling var vellykket til det spesifiserte modul lageret, s&aring; ser det ut til at dette lageret enn&aring; ikke deler noen moduler';
$lang['submit'] = 'Utf&oslash;r';
$lang['text_repository_url'] = 'Linken burde v&aelig;re som dette http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
$lang['prompt_repository_url'] = 'ModulLager Link:';
$lang['title_installation'] = 'Installasjon';
$lang['availmodules'] = 'Tilgjengelige Moduler';
$lang['preferences'] = 'Innstillinger';
$lang['preferencessaved'] = 'Innstillinger lagret';
$lang['repositorycount'] = 'Moduler funnet p&aring; lageret';
$lang['instcount'] = 'Moduler allerede installert';
$lang['availablemodules'] = 'N&aring;v&aelig;rende status for moduler tilgjengelig p&aring; lageret som er valgt n&aring;';
$lang['time_warning'] = 'Om en installasjonsliste har mere enn en eller to moduler, s&aring; v&aelig;r oppmerksom p&aring; at installasjonen kan ta noen minutter. Vennligst v&aelig;r t&aring;lmodig!';
$lang['helptxt'] = 'Hjelp';
$lang['abouttxt'] = 'Om';
$lang['xmltext'] = 'XML Fil';
$lang['nametext'] = 'Modul navn';
$lang['mod_name_ver'] = '%s versjon %s';
$lang['unknown'] = 'Ukjent';
$lang['vertext'] = 'Versjon';
$lang['sizetext'] = 'St&oslash;rrelse';
$lang['statustext'] = 'Status ';
$lang['uptodate'] = 'Oppdatert';
$lang['install'] = 'Installer';
$lang['newerversion'] = 'Nyere versjon installert';
$lang['onlynewesttext'] = 'Vis kun nyeste versjon';
$lang['upgrade'] = 'Oppgradering tilgjengelig';
$lang['error_nosoapconnect'] = 'Kunne ikke koble til SOAP server';
$lang['error_soaperror'] = 'SOAP problem';
$lang['soaperror'] = 'SOAP feil: %s';
$lang['error_norepositoryurl'] = 'Stien til modul lageret er ikke oppgitt';
$lang['friendlyname'] = 'Modulbehandler';
$lang['postinstall'] = 'Etter installerings melding, (f.eks. husk &aring; sette &#039;&#039; rettigheter for &aring; bruke modulen!)';
$lang['postuninstall'] = 'Modul Behandler har blitt avinstallert. Brukere vil ikke lengre ha mulighet til &aring; installere moduler fra fjern-bibliotek. Men, lokalinstallasjoner er fortsatt mulig.';
$lang['really_uninstall'] = 'Er du sikker p&aring; at du vil avinstallere? Du vil miste en masse fin funksjonalitet.';
$lang['uninstalled'] = 'Modul avinnstallert.';
$lang['installed'] = 'Modul versjon %s innstallert.';
$lang['upgraded'] = 'Modul oppgradert til versjon %s.';
$lang['moddescription'] = 'En klient for Modul-lageret, denne modulen tillater forh&aring;ndsvisning og installering av moduler fra fjern-nettsider uten bruk av ftp, eller utpakking av arkiver. Modul XML filer blir lastet ned ved bruk av SOAP, integriteten sjekkes og blir s&aring; utpakket automatisk.';
$lang['back_to_module_manager'] = '&laquo; Tilbake til Modulebehandleren';
$lang['error'] = 'Feil!';
$lang['admindescription'] = 'Et verkt&oslash;y for &aring; hente og installere moduler fra fjern-servere.';
$lang['accessdenied'] = 'Tilgang nektet. Vennligst sjekk dinne rettigheter.';
$lang['changelog'] = '<ul>
<li>Version 1.0. 10 January 2006. Initial Release.</li>
<li>Version 1.1. July, 2006. Released with the 1.0- beta</li>
<li>Version 1.1.1 August, 2006.  Require 1.0.1 of nuSOAP</li>
<li>Version 1.1.2 September, 2006.  Fixed a mistake that resulted in upgrade not not working at all</li>
<li>Version 1.1.3 September, 2006.
  <ul>
  <li>Bumped minimum CMS Version to 1.0</li>
  <li>Now use 1 request to get the complete list of modules from the repository</li>
  <li>Added some missing lang strings</li>
  <li>Added the ability to reset the local cache of repository information</li>
  <li>Added the ability to restore the repository url to factory defaults</li>
  </ul>
</li>
<li>Version 1.1.4 February, 2007.  Now handles the safe mode check, and disables upgrading or installing modules if the permissions are wrong.</li>
<li>Version 1.1.5 September, 2007. New preference to make only latest module version show. Added nice message after saving preferences</li>
</li>
<li>Version 1.1.6 May, 2008. Now show if available modules are incompatible with the current CMS_VERSION.</li>
</li>
<li>Version 1.2 June, 2008.<br/>
This version should reduce the memory requirements of this module, and trade it off for performance on the server, and mroe requests to the server.
   <ul>
    <li>Bumped Minimum CMS Version to 1.3</li>
    <li>Bumped Minimum repository version to 1.1</li>
    <li>Get rid of all of the session stuff</li>
    <li>Add support for requesting modules beginning with a prefix (usually a single letter)</li>
    <li>Add support for requestion only the newest versions of the modules</li>
   </ul>
</li>
<li>Version 1.2.1 August, 2008.<br/>
Added a warning message to the top of the admin display.
</li>
<li>Version 1.3 May, 2009.<br/>
Added dependency checking.
</li>
<li>Version 1.3.3 March, 2010.<br/>
<ul>
  <li>PHP 5.x improvements (specifically remove warnings for PHP 5.3)
  <li>Minor bug fixes.</li>
</ul>
</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>A client for the ModuleRepository, this module allows previewing, and installing modules from remote sites without the need for ftping, or unzipping archives.  Module XML files are downloaded using SOAP, integrity verified, and then expanded automatically.</p>
<h3>How Do I Use It</h3>
<p>In order to use this module, you will need the &#039;Modify Modules&#039; permission, and you will also need the complete, and full URL to a &#039;Module Repository&#039; installation.  You can specify this url in the &#039;Extensions&#039; --&amp;gt; &#039;Module Manager&#039; --&amp;gt; &#039;Preferences&#039; page.</p><br/>
<p>You can find the interface for this module under the &#039;Extensions&#039; menu.  When you select this module, the &#039;Module Repository&#039; installation will automatically be queried for a list of it&#039;s available xml modules.  This list will be cross referenced with the list of currently installed modules, and a summary page displayed.  From here, you can view the descriptive information, the help, and the about information for a module without physically installing it.  You can also choose to upgrade or install modules.</p>
<h3>Support</h3>
<p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
<h3>Copyright and License</h3>
<p>Copyright &amp;copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com">&amp;lt;calguy1000@hotmail.com&amp;gt;</a>. All Rights Are Reserved.</p>
<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
$lang['utmz'] = '156861353.1274726983.2794.62.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/bug/view/4955';
$lang['utma'] = '156861353.179052623084110100.1210423577.1276118103.1276186300.2866';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmb'] = '156861353.1.10.1276186300';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.9.4p3.tgz: cms/modules/ModuleManager/lang/ext/nb_NO.php <==
<?php
$lang['error_searchterm'] = 'Vennligst oppgi noe som er gyldig &aring; s&oslash;ke etter';
$lang['search_noresults'] = 'S&oslash;k lyktes men ingen resultater matchet uttrykket det ble s&oslash;kt etter';
$lang['advancedsearch_help'] = 'Angi ord som skal inkluderes eller ekskluderes fra s&oslash;ket ved hjelp av en + eller -, omslutt eksakte setninger med sitattegn. i.e:   +r&oslash;d -eple +&quot;tekst&quot;';
$lang['search_results'] = 'S&oslash;keresultater';
$lang['prompt_advancedsearch'] = 'Avansert s&oslash;k';
$lang['search_input'] = 'S&oslash;k etter';
$lang['searchterm'] = 'S&oslash;keord';
$lang['search'] = 'S&oslash;k';
$lang['available_updates'] = 'Moduler tilgjengelig for oppdatering, F&oslash;r du oppgraderer, vennligst les utgivelsenotatene i Forge og opprett en sikkerhetskopi av nettstedet.';
$lang['all_modules_up_to_date'] = 'Det er ikke tilgjengelig noen nyere moduler i biblioteket';
$lang['error_module_object'] = 'Feil: Fant ikke en forekomst av %s modulen';
$lang['error_nomatchingmodules'] = 'Feil: kunne ikke finne noen matchende moduler i biblioteket';
$lang['error_nomodules'] = 'Feil: kunne ikke hente listen over installerte moduler';
$lang['upgrade_available'] = 'Nyere versjon tilgjengelig (%s), du har (%s)';
$lang['newversions'] = 'Installerte moduler';
$lang['notice_depends'] = '%s krever f&oslash;lgende handling. Klikk p&aring;  &quot;Installer&quot; for &aring; fortsette.';
$lang['install_submit'] = 'Installer';
$lang['depend_upgrade'] = 'Modul %s trenger &aring; oppgraderes til versjon %s.';
$lang['depend_install'] = 'Modul %s (versjon %s eller senere) m&aring; v&aelig;re installert';
$lang['depend_activate'] = 'Modul %s trenger &aring; aktiveres.';
$lang['action_activated'] = 'Modul %s har blitt aktivert.';
$lang['action_installed'] = 'Modul %s har blitt installert med f&oslash;lgende melding(er): %s';
$lang['action_upgraded'] = 'Modul %s har blitt oppgradert';
$lang['title_installation_complete'] = 'Installasjonsprosessen fullf&oslash;rt!';
$lang['install_with_deps'] = 'Evaluere alle avhengigheter og installer';
$lang['msg_nodependencies'] = 'Denne filen har ikke oppf&oslash;rt noen avhengigheter';
$lang['error_upgrade'] = 'Oppgradering av modul %s feilet!';
$lang['error_skipping'] = 'Hopper over installering/oppgradering av %s p&aring; grunn av feil med &aring; sette opp avhengighetene. Vennligst se meldingen overfor, og fors&oslash;k igjen.';
$lang['dependstxt'] = 'Avhengigheter';
$lang['use_at_your_own_risk'] = 'Bruk p&aring; egen risiko';
$lang['compatibility_disclaimer'] = 'Modulene som vises her er bidratt med av b&aring;de CMS utviklerne og tredjepartsutviklere. Vi gir ingen garanti for at modulene som er tilgjengelige her fungerer, testet, eller kompatible med ditt system. Du oppfordres til &aring; lese informasjonen du finner i hjelp og i &quot;Om&quot; linkene for hver modul f&oslash;r du fors&oslash;ker &aring; installere.';
$lang['notice'] = 'Merk';
$lang['general_notice'] = 'Versjonene som vises her representerer de siste XML filene som er lastet opp til ditt valgte modulbibliotek (vanligvis er dette CMS %s).  De b&oslash;r (men med unntak) representere de siste tilgjengelige versjonene.';
$lang['incompatible'] = 'Ikke kompatibel';
$lang['prompt_settings'] = 'Innstillinger';
$lang['prompt_otheroptions'] = 'Andre opsjoner';
$lang['reset'] = 'Nullstill';
$lang['error_permissions'] = '<strong><em>ADVARSEL:</em></strong> Ikke tilstrekkelige katalog rettigheter for &aring; installere moduler. Du kan ogs&aring; erfare problemer med PHP Safe mode. Vennligst sjekk at safe mode ikke er p&aring;sl&aring;tt og at filsystem rettighetene er tilstrekkelige.';
$lang['error_minimumrepository'] = 'Lager-versjonen er ikke kompatibel med denne modulbehandleren';
$lang['prompt_reseturl'] = 'Sett URL til forh&aring;ndssatt standard';
$lang['prompt_resetcache'] = 'Nullstill lokalt mellomlager for Lager data';
$lang['prompt_dl_chunksize'] = 'Nedlastings bolk-st&oslash;rrelse (Kb)';
$lang['text_dl_chunksize'] = 'Maksimum mengde data &aring; laste ned fra serveren i en bolk (under installering av en modul)';
$lang['error_nofilesize'] = 'Ingen filst&oslash;rrelses parameter oppgitt';
$lang['error_nofilename'] = 'Ingen filnavn parameter oppgitt';
$lang['error_unsatisfiable_dependency'] = 'Kan ikke finne den p&aring;krevde modulen &quot;%s&quot; (versjon %s eller senere) i biblioteket. Denne er direkte p&aring;krevd av %s; dette kan indikere at det er et problem med denne versjonen av modulen i biblioteket. Vennligst kontakt denne modulens opphavsmann.  Avbryter.';
$lang['error_checksum'] = 'Sjekksum feil.  Dette indikerer sansynligvis en korrupt til, enten n&aring;r den ble lastet opp til lagringsplassen, eller et problem med overf&oslash;ring ned til din maskin.';
$lang['cantdownload'] = 'Kan ikke laste ned';
$lang['download'] = 'Last ned og Installer';
$lang['error_moduleinstallfailed'] = 'Modul installasjonen feilet';
$lang['error_connectnomodules'] = 'Selv om tilkobling var vellykket til det spesifiserte modullageret, s&aring; ser det ut til at dette lageret enn&aring; ikke deler noen moduler';
$lang['submit'] = 'Utf&oslash;r';
$lang['text_repository_url'] = 'Linken burde v&aelig;re som dette http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
$lang['prompt_repository_url'] = 'ModulLager Link:';
$lang['title_installation'] = 'Installasjon';
$lang['availmodules'] = 'Tilgjengelige Moduler';
$lang['preferences'] = 'Innstillinger';
$lang['preferencessaved'] = 'Innstillinger lagret';
$lang['repositorycount'] = 'Moduler funnet p&aring; lageret';
$lang['instcount'] = 'Moduler allerede installert';
$lang['availablemodules'] = 'N&aring;v&aelig;rende status for moduler tilgjengelig p&aring; lageret som er valgt n&aring;';
$lang['time_warning'] = 'Om en installasjonsliste har mere enn en eller to moduler, s&aring; v&aelig;r oppmerksom p&aring; at installasjonen kan ta noen minutter. Vennligst v&aelig;r t&aring;lmodig!';
$lang['helptxt'] = 'Hjelp';
$lang['abouttxt'] = 'Om';
$lang['xmltext'] = 'XML Fil';
$lang['nametext'] = 'Modul navn';
$lang['mod_name_ver'] = '%s versjon %s';
$lang['unknown'] = 'Ukjent';
$lang['vertext'] = 'Versjon';
$lang['sizetext'] = 'St&oslash;rrelse';
$lang['statustext'] = 'Status ';
$lang['uptodate'] = 'Oppdatert';
$lang['install'] = 'Installer';
$lang['newerversion'] = 'Nyere versjon installert';
$lang['onlynewesttext'] = 'Vis kun nyeste versjon';
$lang['upgrade'] = 'Oppgradering tilgjengelig';
$lang['error_nosoapconnect'] = 'Kunne ikke koble til SOAP server';
$lang['error_soaperror'] = 'SOAP problem';
$lang['soaperror'] = 'SOAP feil: %s';
$lang['error_norepositoryurl'] = 'Stien til modul lageret er ikke oppgitt';
$lang['friendlyname'] = 'Modulbehandler';
$lang['postinstall'] = 'Modulbehandler modulen har blitt installert';
$lang['postuninstall'] = 'Modulbehandler har blitt avinstallert. Brukere vil ikke lengre ha mulighet til &aring; installere moduler fra fjern-bibliotek. Men, lokalinstallasjoner er fortsatt mulig.';
$lang['really_uninstall'] = 'Er du sikker p&aring; at du vil avinstallere? Du vil miste en masse fin funksjonalitet.';
$lang['uninstalled'] = 'Modul avinnstallert.';
$lang['installed'] = 'Modul versjon %s innstallert.';
$lang['upgraded'] = 'Modul oppgradert til versjon %s.';
$lang['moddescription'] = 'En klient for Modul-lageret, denne modulen tillater forh&aring;ndsvisning og installering av moduler fra fjern-nettsider uten bruk av ftp, eller utpakking av arkiver. Modul XML filer blir lastet ned ved bruk av SOAP, integriteten sjekkes og blir s&aring; utpakket automatisk.';
$lang['back_to_module_manager'] = '&laquo; Tilbake til Modulebehandleren';
$lang['error'] = 'Feil!';
$lang['admindescription'] = 'Et verkt&oslash;y for &aring; hente og installere moduler fra fjern-servere.';
$lang['accessdenied'] = 'Tilgang nektet. Vennligst sjekk dinne rettigheter.';
$lang['changelog'] = '<ul>
<li>Version 1.0. 10 January 2006. Initial Release.</li>
<li>Version 1.1. July, 2006. Released with the 1.0- beta</li>
<li>Version 1.1.1 August, 2006.  Require 1.0.1 of nuSOAP</li>
<li>Version 1.1.2 September, 2006.  Fixed a mistake that resulted in upgrade not not working at all</li>
<li>Version 1.1.3 September, 2006.
  <ul>
  <li>Bumped minimum CMS Version to 1.0</li>
  <li>Now use 1 request to get the complete list of modules from the repository</li>
  <li>Added some missing lang strings</li>
  <li>Added the ability to reset the local cache of repository information</li>
  <li>Added the ability to restore the repository url to factory defaults</li>
  </ul>
</li>
<li>Version 1.1.4 February, 2007.  Now handles the safe mode check, and disables upgrading or installing modules if the permissions are wrong.</li>
<li>Version 1.1.5 September, 2007. New preference to make only latest module version show. Added nice message after saving preferences</li>
</li>
<li>Version 1.1.6 May, 2008. Now show if available modules are incompatible with the current CMS_VERSION.</li>
</li>
<li>Version 1.2 June, 2008.<br/>
This version should reduce the memory requirements of this module, and trade it off for performance on the server, and more requests to the server.
   <ul>
    <li>Bumped Minimum CMS Version to 1.3</li>
    <li>Bumped Minimum repository version to 1.1</li>
    <li>Get rid of all of the session stuff</li>
    <li>Add support for requesting modules beginning with a prefix (usually a single letter)</li>
    <li>Add support for requesting only the newest versions of the modules</li>
   </ul>
</li>
<li>Version 1.2.1 August, 2008.<br/>
Added a warning message to the top of the admin display.
</li>
<li>Version 1.3 May, 2009.<br/>
Added dependency checking.
</li>
<li>Version 1.3.3 March, 2010.<br/>
<ul>
  <li>PHP 5.x improvements (specifically remove warnings for PHP 5.3)</li>
  <li>Minor bug fixes.</li>
</ul>
</li>
<li>Version 1.4 June, 2010.<br/>
<ul>
  <li>Implemented automatic dependency calculation, and one-click installation.</li>
  <li>Assorted usability improvements.</li>
  <li>Minor bug fixes.</li>
</ul>
</li>
</ul>';
$lang['help'] = '<h3>Hva gj&oslash;r denne?</h3>
<p> En klient for ModuleRepository, gir denne modulen forh&aring;ndsvisning, og installere moduler fra eksterne nettsteder uten behov for ft eller unzipping av arkiver. Modul XML-filer lastes ned ved hjelp av SOAP, integritet bekreftet, og deretter pakkes ut automatisk. </p>
<h3> Hvordan bruker jeg denne </h3>
<p> For &aring; kunne bruke denne modulen, trenger du &#039;Endre moduler&#039; tillatelse, og du vil ogs&aring; trenge komplett og fullstendig webadresse til en &#039;Modul Repository&#039; installasjon. Du kan spesifisere denne url i &quot;Utvidelser&quot; -> &quot;Module Manager&quot; -> &quot;Innstillinger&quot;-siden. </p> <br/>
<p> Du kan finne grensesnittet for denne modulen under menyen &#039;Utvidelser&#039;. N&aring;r du velger denne modulen, &#039;Modul Repository&#039; installasjonen vil automatisk bli spurt for en liste over tilgjengelige xml moduler. Denne listen vil bli kryssrefereres med listen over installerte moduler, og en sammendragsside vises. Herfra kan du vise beskrivende informasjon, hjelp, og om informasjon for en modul uten &aring; fysisk installere den. Du kan ogs&aring; velge &aring; oppgradere eller installere moduler. </p>
<h3>Support</h3>
<p> Pr GPL, er denne programvaren leveres som det er. Les teksten av lisensen for full ansvarsfraskrivelse. </p>
<h3>Opphavsrett og lisens</h3>
<p> Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"> <calguy1000@hotmail.com> </a>. Alle rettigheter er reservert. </p>
<p> Denne modulen har blitt utgitt under <a href="http://www.gnu.org/licenses/licenses.html#GPL"> GNU Public License </a>. Du m&aring; godta denne lisensavtalen f&oslash;r du bruker modulen. </p>';
$lang['utma'] = '156861353.4516254727077762000.1214829895.1290588378.1291365970.277';
$lang['utmz'] = '156861353.1290182173.274.25.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
$lang['qca'] = '1214401694-66536492-18746566';
$lang['utmb'] = '156861353.1.10.1291365970';
$lang['utmc'] = '156861353';
?>
